@@ -24,6 +24,12 @@ class DeclarativeContainerInstanceTests(unittest.TestCase):
         self.assertIsNot(container_a1.p12, container_a2.p12)
         self.assertNotEqual(container_a1.providers, container_a2.providers)
 
+    def test_dependencies_attribute(self):
+        container = ContainerA()
+        container.a1 = providers.Dependency()
+        container.a2 = providers.DependenciesContainer()
+        self.assertEqual(container.dependencies, {'a1': container.a1, 'a2': container.a2})
+
     def test_set_get_del_providers(self):
         p13 = providers.Provider()
 
@@ -231,7 +237,3 @@ class DeclarativeContainerInstanceTests(unittest.TestCase):
         self.assertEqual(_init1.shutdown_counter, 2)
         self.assertEqual(_init2.init_counter, 2)
         self.assertEqual(_init2.shutdown_counter, 2)
-
-
-if __name__ == '__main__':
-    unittest.main()
