@@ -1,6 +1,7 @@
 """Dependency injector config providers unit tests."""
 
 import contextlib
+import decimal
 import os
 import sys
 import tempfile
@@ -69,6 +70,33 @@ class ConfigTests(unittest.TestCase):
         self.assertEqual(abc(), 1)
         self.assertEqual(abd(), 2)
 
+    def test_as_int(self):
+        value_provider = providers.Callable(lambda value: value, self.config.test.as_int())
+        self.config.from_dict({'test': '123'})
+
+        value = value_provider()
+
+        self.assertEqual(value, 123)
+
+    def test_as_float(self):
+        value_provider = providers.Callable(lambda value: value, self.config.test.as_float())
+        self.config.from_dict({'test': '123.123'})
+
+        value = value_provider()
+
+        self.assertEqual(value, 123.123)
+
+    def test_as_(self):
+        value_provider = providers.Callable(
+            lambda value: value,
+            self.config.test.as_(decimal.Decimal),
+        )
+        self.config.from_dict({'test': '123.123'})
+
+        value = value_provider()
+
+        self.assertEqual(value, decimal.Decimal('123.123'))
+
     def test_providers_value_override(self):
         a = self.config.a
         ab = self.config.a.b
@@ -82,6 +110,21 @@ class ConfigTests(unittest.TestCase):
         self.assertEqual(abc(), 1)
         self.assertEqual(abd(), 2)
 
+    def test_configuration_option_override_and_reset_override(self):
+        # Bug: https://github.com/ets-labs/python-dependency-injector/issues/319
+        self.config.from_dict({'a': {'b': {'c': 1}}})
+
+        self.assertEqual(self.config.a.b.c(), 1)
+
+        with self.config.set('a.b.c', 'xxx'):
+            self.assertEqual(self.config.a.b.c(), 'xxx')
+        self.assertEqual(self.config.a.b.c(), 1)
+
+        with self.config.a.b.c.override('yyy'):
+            self.assertEqual(self.config.a.b.c(), 'yyy')
+
+        self.assertEqual(self.config.a.b.c(), 1)
+
     def test_providers_with_already_overridden_value(self):
         self.config.override({'a': {'b': {'c': 1, 'd': 2}}})
 
@@ -142,6 +185,13 @@ class ConfigTests(unittest.TestCase):
         with self.assertRaises(AttributeError):
             a.__name__
 
+    def test_missing_key(self):
+        # See: https://github.com/ets-labs/python-dependency-injector/issues/358
+        self.config.override(None)
+        value = self.config.key()
+
+        self.assertIsNone(value)
+
     def test_deepcopy(self):
         provider = providers.Configuration('config')
         provider_copy = providers.deepcopy(provider)
@@ -358,7 +408,6 @@ class ConfigFromIniWithEnvInterpolationTests(unittest.TestCase):
         self.assertEqual(self.config.section1.value1(), 'test-value')
 
 
-
 class ConfigFromYamlTests(unittest.TestCase):
 
     def setUp(self):
